Attribute VB_Name = "tl_ini_mgr"
Option Explicit

Declare Function WritePrivateProfileString Lib "kernel32" Alias "WritePrivateProfileStringA" (ByVal lpApplicationName As String, ByVal lpKeyName As Any, ByVal lpString As Any, ByVal lpFileName As String) As Long
Declare Function GetPrivateProfileInt Lib "kernel32" Alias "GetPrivateProfileIntA" (ByVal lpApplicationName As String, ByVal lpKeyName As String, ByVal nDefault As Long, ByVal lpFileName As String) As Long
Declare Function GetPrivateProfileString Lib "kernel32" Alias "GetPrivateProfileStringA" (ByVal lpApplicationName As String, ByVal lpKeyName As Any, ByVal lpDefault As String, ByVal lpReturnedString As String, ByVal nSize As Long, ByVal lpFileName As String) As Long

Declare Function GetWindowsDirectory Lib "kernel32" Alias "GetWindowsDirectoryA" (ByVal lpBuffer As String, ByVal nSize As Integer) As Integer
Declare Function GetSystemDirectory Lib "kernel32" Alias "GetSystemDirectoryA" (ByVal lpBuffer As String, ByVal nSize As Integer) As Integer

Global WinDir As String
Global WinSys As String
Global fileINI As String

'In general section
Const EWX_LOGOFF = 0
Const EWX_SHUTDOWN = 1
Const EWX_REBOOT = 2
Const EWX_FORCE = 4
Declare Function ExitWindowsEx Lib "User32" (ByVal uFlags As Long, ByVal dwReserved As Long) As Long

Sub StopWindows()

    Static Ret As Long
    Ret = ExitWindowsEx(EWX_FORCE Or EWX_SHUTDOWN, 0)

End Sub



Sub RebootWindows()

    Static Ret As Long
    Ret = ExitWindowsEx(EWX_FORCE Or EWX_REBOOT, 0)

End Sub




'-----------------------------------------------------------
' FUNZIONE: GetWindowsSysDir
'
' Chiama l'API di Windows per ottenere la directory System di Windows
' e verificare che sia presente un separatore di directory finale
'
' Restituisce: la directory \SYSTEM di Windows
'-----------------------------------------------------------
'
Function GetWindowsSysDir() As String

    Dim strBuf As String

    strBuf = Space$(255)

    '
    'Recupera la directory System di Windows e quindi ridimensiona il buffer
    'in base alla lunghezza esatta restituita e aggiunge un separatore
    'di directory (barra rovesciata) se non viene restituito dall'API
    '
    If GetSystemDirectory(strBuf, 255) > 0 Then
        strBuf = StripTerminator(strBuf)
        AddDirSep strBuf
        
        GetWindowsSysDir = UCase$(strBuf)
    Else
        GetWindowsSysDir = ""
    End If
End Function




'-----------------------------------------------------------
' FUNZIONE: GetWindowsDir
'
' Chiama l'API di Windows per ottenere la directory di Windows
' e verificare che sia presente un separatore di directory finale
'
' Restituisce: la directory di Windows
'-----------------------------------------------------------
'
Function GetWindowsDir() As String

    Dim strBuf As String

    strBuf = Space$(255)

    '
    'Recupera la directory di Windows e quindi ridimensiona il buffer
    'in base alla lunghezza esatta restituita e aggiunge un separatore
    'di directory (barra rovesciata) se non viene restituito dall'API
    '
    If GetWindowsDirectory(strBuf, 255) > 0 Then
        strBuf = StripTerminator$(strBuf)
        AddDirSep strBuf
        GetWindowsDir = UCase$(strBuf)
    Else
        GetWindowsDir = ""
    End If
End Function









'----------------------------------------------------------------
' SUB: AddDirSep
' Aggiunge un separatore di percorso per la directory
' (barra rovesciata) alla fine del nome del percorso se
' non esiste gi
'
' IN/OUT: [strPathName] - percorso a cui aggiungere il separatore
'----------------------------------------------------------------
'
Sub AddDirSep(strPathName As String)
    If Right$(RTrim(strPathName), Len("\")) <> "\" Then
        strPathName = RTrim(strPathName) & "\"
    End If
End Sub









'-----------------------------------------------------------
' FUNZIONE: StripTerminator
'
' Restituisce una stringa senza terminatori zero. In genere
' si tratta di una stringa restituita da una chiamata ad
' un'API di Windows.
'
' IN: [strString] - Stringa da cui rimuovere il terminatore
'
' Restituisce: Il valore della stringa passata senza eventuali
'              zero finali.
'-----------------------------------------------------------
'
Function StripTerminator(ByVal strString As String) As String

    Dim intZeroPos As Integer

    intZeroPos = InStr(strString, Chr$(0))
    If intZeroPos > 0 Then
        StripTerminator = Left$(strString, intZeroPos - 1)
    Else
        StripTerminator = strString
    End If
End Function


Function iniREAD(iniSEZ As String, iniKEY As String) As String

    Dim x As Long, l As Integer
    Dim cA As String, A As String, N As Single, T As String
    Dim aL As Single, aT As Single, aW As Single, aH As Single
    
    '#############
    '-------------
    cA = Space$(256)
    x = GetPrivateProfileString(iniSEZ, iniKEY, "", cA, 256, fileINI)
    iniREAD = StripTerminator(cA)
    
End Function



Function iniReadINT(iniSEZ As String, iniKEY As String) As Integer

    Dim x As Long, l As Integer
    Dim cA As String, A As String, N As Single, T As String
    Dim aL As Single, aT As Single, aW As Single, aH As Single
    
    '#############
    '-------------
    cA = Space$(256)
    x = GetPrivateProfileString(iniSEZ, iniKEY, "", cA, 256, fileINI)
    A = StripTerminator(cA)
    If A = "" Then A = "0"
    iniReadINT = CInt(A)
    
End Function




Sub iniWRITE(iniSEZ As String, iniKEY As String, iniTXT As String)

    Dim x As Long, l As Integer, T As String
    Static G As String

    '-------------
    x = WritePrivateProfileString(iniSEZ, iniKEY, iniTXT, fileINI)

End Sub

